# Test Gimp Document

[Gimpformats Index](../README.md#gimpformats-index) / [Test Informal](./index.md#test-informal) / Test Gimp Document

> Auto-generated documentation for [test_informal.test_gimp_document](../../../test_informal/test_gimp_document.py) module.

#### Attributes

- `encoded` - Test encoding and decoding: gimp_img.encode

- `root_group` - Test walking through tree structure: gimp_img.walkTree()


- [Test Gimp Document](#test-gimp-document)
  - [p_header](#p_header)
  - [p_section](#p_section)

## p_header

[Show source in test_gimp_document.py:22](../../../test_informal/test_gimp_document.py#L22)

#### Signature

```python
def p_header(text: str): ...
```



## p_section

[Show source in test_gimp_document.py:15](../../../test_informal/test_gimp_document.py#L15)

#### Signature

```python
def p_section(text: str): ...
```